@@ -75,6 +75,7 @@ class TestCLexerNoErrors(unittest.TestCase):
         self.assertTokensTypes('0123456L', ['INT_CONST_OCT'])
 
         self.assertTokensTypes('0xf7', ['INT_CONST_HEX'])
+        self.assertTokensTypes('0b110', ['INT_CONST_BIN'])
         self.assertTokensTypes('0x01202AAbbf7Ul', ['INT_CONST_HEX'])
 
         # no 0 before x, so ID catches it
@@ -83,6 +84,9 @@ class TestCLexerNoErrors(unittest.TestCase):
         # - is MINUS, the rest a constnant
         self.assertTokensTypes('-1', ['MINUS', 'INT_CONST_DEC'])
 
+    def test_special_names(self):
+        self.assertTokensTypes('sizeof offsetof', ['SIZEOF', 'OFFSETOF'])
+
     def test_floating_constants(self):
         self.assertTokensTypes('1.5f', ['FLOAT_CONST'])
         self.assertTokensTypes('01.5', ['FLOAT_CONST'])
@@ -313,6 +317,7 @@ class TestCLexerNoErrors(unittest.TestCase):
         #pragma {pack: 2, smack: 3}
         #pragma <includeme.h> "nowit.h"
         #pragma "string"
+        #pragma somestring="some_other_string"
         #pragma id 124124 and numbers 0235495
         59
         '''
@@ -325,7 +330,7 @@ class TestCLexerNoErrors(unittest.TestCase):
         self.assertEqual(t1.type, 'INT_CONST_DEC')
         t2 = self.clex.token()
         self.assertEqual(t2.type, 'INT_CONST_DEC')
-        self.assertEqual(t2.lineno, 10)
+        self.assertEqual(t2.lineno, 11)
 
 
 
@@ -413,5 +418,3 @@ class TestCLexerErrors(unittest.TestCase):
 
 if __name__ == '__main__':
     unittest.main()
-
-
